Module blaxel.models.histogram_bucket
=====================================

Classes
-------

`HistogramBucket(count: blaxel.types.Unset | int = <blaxel.types.Unset object>, end: blaxel.types.Unset | float = <blaxel.types.Unset object>, start: blaxel.types.Unset | float = <blaxel.types.Unset object>)`
:   Histogram bucket
    
    Attributes:
        count (Union[Unset, int]): Count
        end (Union[Unset, float]): End
        start (Union[Unset, float]): Start
    
    Method generated by attrs for class HistogramBucket.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `count: blaxel.types.Unset | int`
    :

    `end: blaxel.types.Unset | float`
    :

    `start: blaxel.types.Unset | float`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :